==> jc-1.4.0.tar.gz: soot/jimple/internal/JMulExpr.h <==
// public class soot.jimple.internal.JMulExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr
// @dep_class 1eb1173a7303aca6 soot_jimple_internal_AbstractJimpleFloatBinopExpr
// @dep_class 335ec840bd6235b soot_jimple_internal_JMulExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleFloatBinopExpr

#include "soot/jimple/internal/AbstractJimpleFloatBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JMulExpr_H_
#define _JC_soot_jimple_internal_JMulExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JMulExpr$sub_refs	_jc_soot_jimple_internal_JMulExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JMulExpr$sub_nonrefs	_jc_soot_jimple_internal_JMulExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JMulExpr$refs	_jc_soot_jimple_internal_JMulExpr$refs;
typedef struct _jc_soot_jimple_internal_JMulExpr$nonrefs	_jc_soot_jimple_internal_JMulExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JMulExpr$object	_jc_soot_jimple_internal_JMulExpr$object;

typedef const struct _jc_soot_jimple_internal_JMulExpr$vmethods	_jc_soot_jimple_internal_JMulExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JMulExpr$vtable	_jc_soot_jimple_internal_JMulExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JMulExpr$vtype	_jc_soot_jimple_internal_JMulExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JMulExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_internal_JMulExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JMulExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JMulExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JMulExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_soot_Type$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JMulExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *);
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_soot_Type$object *);
};

// Vtable
struct _jc_soot_jimple_internal_JMulExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
	_jc_soot_jimple_internal_JMulExpr$vmethods	soot_jimple_internal_JMulExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JMulExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JMulExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JMulExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JMulExpr$refs {
    _jc_soot_jimple_internal_JMulExpr$sub_refs	soot_jimple_internal_JMulExpr;
    _jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JMulExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JMulExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
    _jc_soot_jimple_internal_JMulExpr$sub_nonrefs	soot_jimple_internal_JMulExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JMulExpr$object {
	_jc_soot_jimple_internal_JMulExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JMulExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JMulExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JMulExpr$vtype _jc_soot_jimple_internal_JMulExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JMulExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JMulExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JMulExpr_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/internal/JMulExpr.h <==
// public class soot.jimple.internal.JMulExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class b3123b7fa425fe58 soot_jimple_internal_AbstractFloatBinopExpr
// @dep_class 1eb1173a7303aca6 soot_jimple_internal_AbstractJimpleFloatBinopExpr
// @dep_class 335ec840bd6235b soot_jimple_internal_JMulExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractJimpleFloatBinopExpr

#include "soot/jimple/internal/AbstractJimpleFloatBinopExpr.h"

#ifndef _JC_soot_jimple_internal_JMulExpr_H_
#define _JC_soot_jimple_internal_JMulExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Type$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_internal_JMulExpr$sub_refs	_jc_soot_jimple_internal_JMulExpr$sub_refs;
typedef struct _jc_soot_jimple_internal_JMulExpr$sub_nonrefs	_jc_soot_jimple_internal_JMulExpr$sub_nonrefs;
typedef struct _jc_soot_jimple_internal_JMulExpr$refs	_jc_soot_jimple_internal_JMulExpr$refs;
typedef struct _jc_soot_jimple_internal_JMulExpr$nonrefs	_jc_soot_jimple_internal_JMulExpr$nonrefs;
typedef struct _jc_soot_jimple_internal_JMulExpr$object	_jc_soot_jimple_internal_JMulExpr$object;

typedef const struct _jc_soot_jimple_internal_JMulExpr$vmethods	_jc_soot_jimple_internal_JMulExpr$vmethods;
typedef const struct _jc_soot_jimple_internal_JMulExpr$vtable	_jc_soot_jimple_internal_JMulExpr$vtable;
typedef const struct _jc_soot_jimple_internal_JMulExpr$vtype	_jc_soot_jimple_internal_JMulExpr$vtype;

// Constructors
extern void _jc_soot_jimple_internal_JMulExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_internal_JMulExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JMulExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_internal_JMulExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_internal_JMulExpr$method$makeBafInst$e751b63f18bed081(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$getSymbol$ce407d9fb7da8b41;
extern _jc_method _jc_soot_jimple_internal_JMulExpr$method_info$makeBafInst$e751b63f18bed081;

// Virtual methods structure
struct _jc_soot_jimple_internal_JMulExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*makeBafInst$e751b63f18bed081)(_jc_env *, struct _jc_soot_jimple_internal_JMulExpr$object *, struct _jc_soot_Type$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_internal_JMulExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractFloatBinopExpr$vmethods	soot_jimple_internal_AbstractFloatBinopExpr;
	_jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$vmethods	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
	_jc_soot_jimple_internal_JMulExpr$vmethods	soot_jimple_internal_JMulExpr;
};

// Vtype
struct _jc_soot_jimple_internal_JMulExpr$vtype {
	_jc_type			type;
	_jc_soot_jimple_internal_JMulExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_internal_JMulExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_internal_JMulExpr$refs {
    _jc_soot_jimple_internal_JMulExpr$sub_refs	soot_jimple_internal_JMulExpr;
    _jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_refs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_internal_JMulExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_internal_JMulExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractFloatBinopExpr;
    _jc_soot_jimple_internal_AbstractJimpleFloatBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractJimpleFloatBinopExpr;
    _jc_soot_jimple_internal_JMulExpr$sub_nonrefs	soot_jimple_internal_JMulExpr;
};

// Object instance structure
struct _jc_soot_jimple_internal_JMulExpr$object {
	_jc_soot_jimple_internal_JMulExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_internal_JMulExpr$vtype	*vtype;
	_jc_soot_jimple_internal_JMulExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_internal_JMulExpr$vtype _jc_soot_jimple_internal_JMulExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_internal_JMulExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_internal_JMulExpr$class_object;

#endif	/* _JC_soot_jimple_internal_JMulExpr_H_ */
